#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-8Lh8RHSDJkbJ4D6lSsPrmd
key:                  hslua-module-version-1.1.1-8Lh8RHSDJkbJ4D6lSsPrmd
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  46c323e5763742c1a255b581bb082b15
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-version-1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-8Lh8RHSDJkbJ4D6lSsPrmd
depends:
    base-4.18.2.1 filepath-1.4.300.1
    hslua-core-2.3.2-LKfBNQBzih4B11MsDUkzCU
    hslua-marshalling-2.3.1-L0gS8fOJVsC3PgWUxw8tfr
    hslua-packaging-2.3.1-DLo447s2K6F6sfKMAWJXie text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

